/*-----------------------------------------------------------------------*/
/* filename -       colordlg.hpp                                         */
/*                                                                       */
/* function(s)                                                           */
/*                  declarations for TPatternCluster, TPatternButtons,   */
/*                  and TVColorDialog classes                            */
/*                                                                       */
/*                  this shareware version contains a "nag screen"       */
/*                  dialog which is not present in the registered        */
/*                  version                                              */
/*                                                                       */
/* author -         Michael "Mick" Newton                                */
/*                                                                       */
/*-----------------------------------------------------------------------*/

/*-----------------------------------------------------------------------*/
/*                                                                       */
/*    COLORDLG.HPP                                                       */
/*                                                                       */
/*    TVColorDialog shareware version 2.0                                */
/*    (C) Copyright 1992,1993 Comsoft Software                           */
/*    All Rights Reserved.                                               */
/*                                                                       */
/*                                                                       */
/*-----------------------------------------------------------------------*/


#if !defined __COLORDLG_HPP
#define __COLORDLG_HPP


// Forward references to Turbo Vision classes *****************************

class far TColorDisplay;
class far TColorGroup;
class far TColorGroupList;
class far TColorSelector;
class far TDialog;
class far TEvent;
class far TLabel;
class far TMonoSelector;
class far TPalette;
class far TPoint;
class far TRect;
class far TStreamable;
class far TStringCollection;
class far TView;
class far ipstream;
class far opstream;





// Constants **************************************************************

// Release version string
#define colorDlgVerStr "2.0"

// Maximum number of different pattern characters allowed in
// pattern selector
#define MAXPATTERNS 16

// TPatternCluster broadcast commands
const ushort
   cmPatternItemPressed = 58,
   cmPatternItemFocused = 59;





// Data structures ********************************************************

// for getData() and setData() in TVColorDialog
struct TVColorDialogRec
{
   TPalette *pal;                 // Pointer to the palette to copy
   ushort pattern;                // Pattern selector radiobutton data
};


// For broadcast event in movedTo() and press() in TPatternCluster
struct TPatternItemRec
{
   TView *view;
   short item;
};





// TPatternCluster ********************************************************

class TPatternCluster : public TView
{
   public:
      TPatternCluster(const TRect& bounds,
                      const char *aString,
                      uchar aBackground);
      virtual void shutDown();
      virtual TPalette& getPalette() const;
      virtual ushort dataSize();
      virtual void setData(void *rec);
      virtual void getData(void *rec);
      virtual ushort getHelpCtx();
      virtual void handleEvent(TEvent& event);
      void drawBox(const char *icon, char marker);
      virtual Boolean mark(int item);
      virtual void press(int item);
      virtual void movedTo(int item);
      virtual void setState(ushort aState, Boolean enable);
      virtual void setColor(uchar *aColor);
      static const char * const near name;
      static TStreamable *build();
   protected:
      ushort value;
      uchar background;
      int selected;
      TStringCollection *strings;
      TPatternCluster(StreamableInit);
      virtual void write(opstream&);
      virtual void *read(ipstream&);
   private:
      int column(int item);
      int row(int item);
      int findSel(TPoint point);
      virtual const char *streamableName() const
         {
         return name;
         };
};


inline ipstream& operator >> (ipstream& is, TPatternCluster& cl)
   {
   return is >> (TStreamable&) cl;
   };

inline ipstream& operator >> (ipstream& is, TPatternCluster*& cl)
   {
   return is >> (void *&) cl;
   };

inline opstream& operator << (opstream& os, TPatternCluster& cl)
   {
   return os << (TStreamable&) cl;
   };

inline opstream& operator << (opstream& os, TPatternCluster* cl)
   {
   return os << (TStreamable *) cl;
   };





// TPatternButtons ********************************************************

class TPatternButtons : public TPatternCluster
{
   public:
      TPatternButtons(const TRect& bounds,
                      const char *aString,
                      uchar aBackground);
      virtual void draw();
      virtual Boolean mark(int item);
      virtual void movedTo(int item);
      virtual void press(int item);
      virtual void setData(void *rec);
      virtual void getData(void *rec);
      static const char * const near name;
      static TStreamable *build();
   protected:
      TPatternButtons(StreamableInit);
   private:
      static const char * near button;
      virtual const char *streamableName() const
         {
         return name;
         };
};


inline ipstream& operator >> (ipstream& is, TPatternButtons& cl)
   {
   return is >> (TStreamable&) cl;
   };

inline ipstream& operator >> (ipstream& is, TPatternButtons*& cl)
   {
   return is >> (void *&) cl;
   };

inline opstream& operator << (opstream& os, TPatternButtons& cl)
   {
   return os << (TStreamable&) cl;
   };

inline opstream& operator << (opstream& os, TPatternButtons* cl)
   {
   return os << (TStreamable *) cl;
   };





// TVColorDialog **********************************************************

class TVColorDialog : public TDialog
{
   public:
      TVColorDialog(TPalette *aPalette,
                    TColorGroup *aGroups,
                    const char *aString,
                    Boolean addHelpButton = False);
      virtual void shutDown();
      virtual ushort dataSize();
      virtual void setData(void *rec);
      virtual void getData(void *rec);
      virtual void handleEvent(TEvent& event);
      static const char * const near name;
      static TStreamable *build();
   protected:
      TPalette *pal;
      TColorDisplay *display;
      TColorGroupList *groups;
      TLabel *forgroundLabel;
      TColorSelector *forgroundSelector;
      TLabel *backgroundLabel;
      TColorSelector *backgroundSelector;
      TLabel *monoLabel;
      TMonoSelector *monoSelector;
      TLabel *patternLabel;
      TPatternButtons *patternSelector;
      TVColorDialog(StreamableInit);
      virtual void write(opstream&);
      virtual void *read(ipstream&);
   private:
      static const char * near colors;
      static const char * near groupText;
      static const char * near itemText;
      static const char * near forgroundText;
      static const char * near backgroundText;
      static const char * near patternText;
      static const char * near displayedText;
      static const char * near colorText;
      static const char * near okText;
      static const char * near cancelText;
      static const char * near helpText;
      virtual const char *streamableName() const
         {
         return name;
         };
};


inline ipstream& operator >> (ipstream& is, TVColorDialog& cl)
   {
   return is >> (TStreamable&) cl;
   };

inline ipstream& operator >> (ipstream& is, TVColorDialog*& cl)
   {
   return is >> (void *&) cl;
   };

inline opstream& operator << (opstream& os, TVColorDialog& cl)
   {
   return os << (TStreamable&) cl;
   };

inline opstream& operator << (opstream& os, TVColorDialog* cl)
   {
   return os << (TStreamable *) cl;
   }


#endif

//                                End of COLORDLG.HPP



